@@ -31,15 +31,13 @@ class MobileCommand(object):
     # Appium Commands
     GET_APP_STRINGS = 'getAppStrings'
     PRESS_KEYCODE = 'pressKeyCode'
-    # TODO: remove when new Appium is out
-    KEY_EVENT = 'keyEvent'
+    KEY_EVENT = 'keyEvent' # Needed for Selendroid
     LONG_PRESS_KEYCODE = 'longPressKeyCode'
     GET_CURRENT_ACTIVITY = 'getCurrentActivity'
     SET_IMMEDIATE_VALUE = 'setImmediateValue'
     PULL_FILE = 'pullFile'
     PULL_FOLDER = 'pullFolder'
     PUSH_FILE = 'pushFile'
-    COMPLEX_FIND = 'complexFind'
     BACKGROUND = 'background'
     IS_APP_INSTALLED = 'isAppInstalled'
     INSTALL_APP = 'installApp'
@@ -51,3 +49,7 @@ class MobileCommand(object):
     SHAKE = 'shake'
     RESET = 'reset'
     HIDE_KEYBOARD = 'hideKeyboard'
+    REPLACE_KEYS = 'replaceKeys'
+    START_ACTIVITY = 'startActivity'
+    GET_SETTINGS = 'getSettings'
+    UPDATE_SETTINGS = 'updateSettings'
