@@ -350,7 +350,7 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.HIDE_KEYBOARD, data)
         return self
 
-    # TODO: remove when new Appium is out
+    # Needed for Selendroid
     def keyevent(self, keycode, metastate=None):
         """Sends a keycode to the device. Android only. Possible keycodes can be
         found in http://developer.android.com/reference/android/view/KeyEvent.html.
@@ -457,17 +457,6 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.PUSH_FILE, data)
         return self
 
-    def complex_find(self, selector):
-        """Performs a find for elements in the current application.
-
-        :Args:
-         - selector - an array of selection criteria
-        """
-        data = {
-            'selector': selector,
-        }
-        return self.execute(Command.COMPLEX_FIND, data)['value']
-
     def background_app(self, seconds):
         """Puts the application in the background on the device for a certain
         duration.
@@ -530,6 +519,27 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.CLOSE_APP)
         return self
 
+    def start_activity(self, app_package, app_activity, app_wait_package='', app_wait_activity=''):
+        """Opens an arbitrary activity during a test. If the activity belongs to
+        another application, that application is started and the activity is opened.
+
+        This is an Android-only method.
+
+        :Args:
+        - app_package - The package containing the activity to start.
+        - app_activity - The activity to start.
+        - app_wait_package - Begin automation after this package starts.
+        - app_wait_activity - Begin automation after this activity starts.
+        """
+        data = {
+            'appPackage': app_package,
+            'appActivity': app_activity,
+            'appWaitPackage': app_wait_package,
+            'appWaitActivity': app_wait_activity
+        }
+        self.execute(Command.START_ACTIVITY, data)
+        return self
+
     def end_test_coverage(self, intent, path):
         """Ends the coverage collection and pull the coverage.ec file from the device.
         Android only.
@@ -643,6 +653,24 @@ class WebDriver(webdriver.Remote):
         """
         return self.execute(Command.GET_ACTIVE_IME_ENGINE, {})['value']
 
+    def get_settings(self):
+        """Returns the appium server Settings for the current session.
+        Do not get Settings confused with Desired Capabilities, they are
+        separate concepts. See https://github.com/appium/appium/blob/master/docs/en/advanced-concepts/settings.md
+        """
+        return self.execute(Command.GET_SETTINGS, {})['value']
+
+    def update_settings(self, settings):
+        """Set settings for the current session.
+        For more on settings, see: https://github.com/appium/appium/blob/master/docs/en/advanced-concepts/settings.md
+
+        :Args:
+         - settings - dictionary of settings to apply to the current test session
+        """
+        data = {"settings": settings}
+
+        self.execute(Command.UPDATE_SETTINGS, data)
+        return self
 
     def _addCommands(self):
         self.command_executor._commands[Command.CONTEXTS] = \
@@ -657,7 +685,7 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/touch/multi/perform')
         self.command_executor._commands[Command.GET_APP_STRINGS] = \
             ('POST', '/session/$sessionId/appium/app/strings')
-        # TODO: remove when new Appium is out
+        # Needed for Selendroid
         self.command_executor._commands[Command.KEY_EVENT] = \
             ('POST', '/session/$sessionId/appium/device/keyevent')
         self.command_executor._commands[Command.PRESS_KEYCODE] = \
@@ -674,8 +702,6 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/pull_folder')
         self.command_executor._commands[Command.PUSH_FILE] = \
             ('POST', '/session/$sessionId/appium/device/push_file')
-        self.command_executor._commands[Command.COMPLEX_FIND] = \
-            ('POST', '/session/$sessionId/appium/app/complex_find')
         self.command_executor._commands[Command.BACKGROUND] = \
             ('POST', '/session/$sessionId/appium/app/background')
         self.command_executor._commands[Command.IS_APP_INSTALLED] = \
@@ -684,6 +710,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/install_app')
         self.command_executor._commands[Command.REMOVE_APP] = \
             ('POST', '/session/$sessionId/appium/device/remove_app')
+        self.command_executor._commands[Command.START_ACTIVITY] = \
+            ('POST', '/session/$sessionId/appium/device/start_activity')
         self.command_executor._commands[Command.LAUNCH_APP] = \
             ('POST', '/session/$sessionId/appium/app/launch')
         self.command_executor._commands[Command.CLOSE_APP] = \
@@ -714,6 +742,12 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/ime/deactivate')
         self.command_executor._commands[Command.GET_ACTIVE_IME_ENGINE] = \
             ('GET', '/session/$sessionId/ime/active_engine')
+        self.command_executor._commands[Command.REPLACE_KEYS] = \
+            ('POST', '/session/$sessionId/appium/element/$elementId/replace_value')
+        self.command_executor._commands[Command.GET_SETTINGS] = \
+            ('GET', '/session/$sessionId/appium/settings')
+        self.command_executor._commands[Command.UPDATE_SETTINGS] = \
+            ('POST', '/session/$sessionId/appium/settings')
 
 
 # monkeypatched method for WebElement
